Coverage report

# Coverage report: 71%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 491 | 142 | 0 | 71%
/home/kale/hacking/projects/tich_me/tich_me/__init__.py | 6 | 0 | 0 | 100%
/home/kale/hacking/projects/tich_me/tich_me/analysis.py | 70 | 48 | 0 | 31%
/home/kale/hacking/projects/tich_me/tich_me/app.py | 4 | 0 | 0 | 100%
/home/kale/hacking/projects/tich_me/tich_me/main.py | 53 | 53 | 0 | 0%
/home/kale/hacking/projects/tich_me/tich_me/model.py | 188 | 13 | 0 | 93%
/home/kale/hacking/projects/tich_me/tich_me/scrape.py | 170 | 28 | 0 | 84%

No items found using the specified filter.